@@ -110,7 +110,7 @@ class Session:
         return model(**resp.json())
 
     def _get_models(
-        self, url: str, model: Type[BaseModel], limit: int = 200
+        self, url: str, model: Type[BaseModel], limit: int = 500
     ) -> Iterator[BaseModel]:
         next_url = update_query(url, {"limit": limit})
         while next_url:
@@ -203,6 +203,7 @@ class Session:
 
         Raises ``ValueError`` if the title is non-unique or if no match is found.
         """
+        logging.info("get_block")
         project_obj = (
             project if isinstance(project, Project) else self.get_project(project)
         )
@@ -236,7 +237,9 @@ class Session:
             raise ValueError(
                 f"trying to fetch version {version} when latest version is {block.latest_version}"
             )
-        version_obj = self._get_model(f"{block.links.self}/versions/{version}", BlockVersion)
+        version_obj = self._get_model(
+            f"{block.links.self}/versions/{version}", BlockVersion
+        )
         return version_obj
 
     def get_version_with_children(
@@ -249,10 +252,12 @@ class Session:
             raise ValueError(
                 f"trying to fetch version {version} when latest version is {block.latest_version}"
             )
-        return self._get_model(
-            f"{block.links.self}/versions/{version}/children/?format={fmt}",
-            ChildrenList,
-        )
+        try:
+            url = f"{block.links.self}/versions/{version}/children/?format={fmt}"
+            return self._get_model(url, ChildrenList)
+        except ValueError as err:
+            logging.error(f"Failed to fetch children {url}")
+            raise err
 
     def download_version(
         self,
